@@ -272,7 +272,7 @@ JNIEXPORT jintArray JNICALL Java_org_gnu_gconf_ConfClient_gconf_1client_1all_1en
 	jintArray ar = (*env)->NewIntArray(env, len);
 	for (i = 0; i < len; i++) {
 		GSList *item = g_slist_nth(val, i);
-		(*env)->SetIntArrayRegion(env, ar, i, 1, (jint)item->data);
+		(*env)->SetIntArrayRegion(env, ar, i, 1, (jint*)item->data);
 	}
 	(*env)->ReleaseStringUTFChars(env, dir, str);
 	(*env)->ReleaseIntArrayElements(env, exception, (jint*)err, 0);
@@ -382,7 +382,7 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gconf_ConfClient_gconf_1client_1get_1stri
 	gchar* val = gconf_client_get_string((GConfClient*)client, str, &err);
 	(*env)->ReleaseStringUTFChars(env, key, str);
 	if (err != NULL) {
-		(*env)->SetIntArrayRegion(env, exception, 0, 1, (jint)err);
+		(*env)->SetIntArrayRegion(env, exception, 0, 1, (jint*)err);
 	}
 	return (*env)->NewStringUTF(env, val);
 }
